# Terms and Conditions

As per [issue #1](https://github.com/aviaryan/python-gsearch/issues/1), scraping Google Search results violates their ToS.

The recommended method by Google is to use their API.

> JSON/Atom Custom Search API provides 100 search queries per day for free. If you need more, you may sign up for billing in the API Console. Additional requests cost $5 per 1000 queries, up to 10k queries per day.

**By using this library, you agree that the author won't be responsible for any damage that comes to you and/or your property.
You hereby agree to take all responsibilities for using this library.
The author is merely a developer who created this library but you are the one who is using it.**


### Helpful Links

* https://benbernardblog.com/web-scraping-and-crawling-are-perfectly-legal-right/
